@@ -10,7 +10,7 @@ def call_model(*, model_name, input):
 
     project_name = project_client.get_project()["name"]
 
-    _model = slai.model(model_name=model_name, project_name=project_name)
+    _model = slai.model(f"{project_name}/{model_name}")
 
     for i in range(100):
         start = time.time()
